r252761 - in zettwerk.ui/trunk: . docs zettwerk/ui zettwerk/ui/browser zettwerk/ui/browser/scripts zettwerk/ui/locales zettwerk/ui/locales/de/LC_MESSAGES zettwerk/ui/locales/en/LC_MESSAGES zettwerk/ui/locales/es/LC_MESSAGES zettwerk/ui/locales/fr/LC_MESSAGES zettwerk/ui/static zettwerk/ui/tool
"J??rg Kubaile" <svn-changes-z4DKO/[email protected]> Fri, 11 Apr 2014 07:35:10 +0000 (UTC)
| Newsgroups | gmane.comp.web.zope.plone.collective.cvs |
|---|---|
| Message-ID | <[email protected]> |
Author: jkubaile
Date: Fri Apr 11 07:35:08 2014
New Revision: 252761
Modified:
zettwerk.ui/trunk/MANIFEST.in
zettwerk.ui/trunk/docs/HISTORY.txt
zettwerk.ui/trunk/setup.py
zettwerk.ui/trunk/zettwerk/ui/browser/cp_view.py
zettwerk.ui/trunk/zettwerk/ui/browser/scripts/cp.js
zettwerk.ui/trunk/zettwerk/ui/filesystem.py
zettwerk.ui/trunk/zettwerk/ui/locales/de/LC_MESSAGES/zettwerk.ui.mo
zettwerk.ui/trunk/zettwerk/ui/locales/de/LC_MESSAGES/zettwerk.ui.po
zettwerk.ui/trunk/zettwerk/ui/locales/en/LC_MESSAGES/zettwerk.ui.mo
zettwerk.ui/trunk/zettwerk/ui/locales/en/LC_MESSAGES/zettwerk.ui.po
zettwerk.ui/trunk/zettwerk/ui/locales/es/LC_MESSAGES/zettwerk.ui.mo
zettwerk.ui/trunk/zettwerk/ui/locales/es/LC_MESSAGES/zettwerk.ui.po
zettwerk.ui/trunk/zettwerk/ui/locales/fr/LC_MESSAGES/zettwerk.ui.mo
zettwerk.ui/trunk/zettwerk/ui/locales/fr/LC_MESSAGES/zettwerk.ui.po
zettwerk.ui/trunk/zettwerk/ui/locales/zettwerk.ui.pot
zettwerk.ui/trunk/zettwerk/ui/static/gui.js
zettwerk.ui/trunk/zettwerk/ui/tool/tool.py
Log:
switch to manual theme adding
Modified: zettwerk.ui/trunk/MANIFEST.in
==============================================================================
--- zettwerk.ui/trunk/MANIFEST.in (original)
+++ zettwerk.ui/trunk/MANIFEST.in Fri Apr 11 07:35:08 2014
@@ -1,2 +1,3 @@
recursive-include zettwerk *
-global-exclude *pyc
\ No newline at end of file
+global-exclude *pyc
+graft docs
\ No newline at end of file
Modified: zettwerk.ui/trunk/docs/HISTORY.txt
==============================================================================
--- zettwerk.ui/trunk/docs/HISTORY.txt (original)
+++ zettwerk.ui/trunk/docs/HISTORY.txt Fri Apr 11 07:35:08 2014
@@ -4,13 +4,9 @@
2.0 (unreleased)
----------------
-- Nothing changed yet.
-
-
-1.1.1 (2012-09-24)
-------------------
-
-- Nothing changed yet.
+- Plone 4.3 compatibility (for < 4.3 use < 2.0)
+- removed themeroller integration
+- added readme for manual theme integration
1.1.0 (2012-09-21)
Modified: zettwerk.ui/trunk/setup.py
==============================================================================
--- zettwerk.ui/trunk/setup.py (original)
+++ zettwerk.ui/trunk/setup.py Fri Apr 11 07:35:08 2014
@@ -29,8 +29,7 @@
install_requires=[
'setuptools',
# -*- Extra requirements: -*-
- 'collective.js.jqueryui>1.8.13',
- 'plone.app.theming>=1.0b9'
+ 'collective.js.jqueryui>1.10',
],
extras_require={
'test': ['plone.app.testing', 'mocker', 'gocept.selenium']
Modified: zettwerk.ui/trunk/zettwerk/ui/browser/cp_view.py
==============================================================================
--- zettwerk.ui/trunk/zettwerk/ui/browser/scripts/cp.js (original)
+++ zettwerk.ui/trunk/zettwerk/ui/browser/scripts/cp.js Fri Apr 11 07:35:08 2014
@@ -1,145 +1,3 @@
-var jquitr = {}
-// modified output of http://jqueryui.com/themeroller/developertool/developertool.js.php
-// this is used to make edit of existing themes work (note the hash for the iframe src)
-var wrapper = function(hash) {
- jquitr.trString = '';
- var addThemeRoller = function(){
- if(jq('#inline_themeroller').size() > 0){
- jq('#inline_themeroller').fadeIn();
- }
- else {
- jq('<div id="inline_themeroller" style="display: none; position: fixed; background: #111; top: 25px; right: 25px; padding: 22px 0 15px 4px;width: 245px;height:400px; -webkit-border-radius: 6px; -moz-border-radius: 6px; z-index: 9999999;">'+
- '<a href="#" class="closeTR" style="font-family: Verdana, sans-serif; font-size: 10px; display: block; position: absolute; right: 0; top: 2px; text-align: right; background: url(http://jqueryui.com/themeroller/developertool/icon_bookmarklet_close.gif) 0 2px no-repeat; width: 16px;height: 16px; color: #fff; text-decoration: none;" title="Close ThemeRoller"></a>'+
- '<iframe name="trApp" src="http://jqueryui.com/themeroller/developertool/appinterface.php#'+hash+'" style="background: transparent; overflow: auto; width: 240px;height:100%;border: 0;" frameborder="0" ></iframe>'+
- '</div>')
- .appendTo('body')
- .draggable({
- start: function(){
- jq('<div id="div_cover" />').appendTo('#inline_themeroller').css({width: jq(this).width(), height: jq(this).height(), position: 'absolute', top: 0, left:0});
- },
- stop: function(){
- jq('#div_cover').remove();
- },
- opacity: 0.6,
- cursor: 'move'
- })
- .resizable({
- start: function(){
- jq(this).find('iframe').hide();
- },
- stop: function(){
- jq(this).find('iframe').show();
- },
- handles: 's'
- })
- .find('a.closeTR').click(function(){
- closeThemeRoller();
- })
- .end()
- .find('.ui-resizable-s').css({
- background: 'url(http://jqueryui.com/themeroller/developertool/icon_bookmarklet_dragger.gif) 50% 50% no-repeat',
- border: 'none',
- height: '14px',
- dipslay: 'block',
- cursor: 'resize-s',
- bottom: '-3px'
- })
- .end()
- .css('cursor', 'move')
- .fadeIn();
- }
- reloadCSS();
- };
- //close dev tool
- var closeThemeRoller = function () {
- jq('#inline_themeroller').fadeOut();
- };
- //get current url hash
- var getHash = function () {
- var currSrc = window.location.hash;
- if (currSrc.indexOf('#') > -1) {
- currSrc = currSrc.split('#')[1];
- }
- return currSrc;
- };
- //recursive reload call
- var reloadCSS = function(){
- var currSrc = getHash(), cssLink;
- if(jquitr.trString !== currSrc && currSrc !== ''){
- jquitr.trString = currSrc;
- cssLink = '<link href="http://jqueryui.com/themeroller/css/parseTheme.css.php?'+ currSrc +'" type="text/css" rel="Stylesheet" />';
- //works for both 1.6 final and early rc's
- if( jq("link[href*=parseTheme.css.php], link[href=ui.theme.css]").size() > 0){
- jq("link[href*=parseTheme.css.php]:last, link[href=ui.theme.css]:last").eq(0).after(cssLink);
- } else {
- jq("head").append(cssLink);
- }
- if( jq("link[href*=parseTheme.css.php]").size() > 3){
- jq("link[href*=parseTheme.css.php]:first").remove();
- }
- }
- window.setTimeout(reloadCSS, 1000);
- };
- // Actually add the roller
- addThemeRoller();
-};
-
-var callThemeroller = function(hash) {
- // give the current hash to the themeroller, so he can take the settings of the theme
- if (hash) {
- window.location.href += '#'+hash;
- }
- if (!/Firefox[\/\s](\d+\.\d+)/.test(navigator.userAgent)) {
- alert(sorry_only_firefox);
- return false;
- };
-
- wrapper(hash);
- jq('label[for=form.download]').parent().show();
-};
-
var createDLDirectory = function() {
document.location.href = 'portal_ui_tool/createDLDirectory';
};
-
-// change the submit handler to include the hash of the themeroller theme
-jq(document).ready(function() {
- // hide the download input - its only shown when themeroller opens
- jq('label[for=form.download]').parent().hide();
-
- // make the form "multiSubmitable"
- jq('input[name=form.actions.save]').addClass('allowMultiSubmit');
-
- jq('input[name=form.actions.save]').click(function() {
- var hash = jquitr.trString;
- var download_name = jq('input[name=form.download]').val();
-
- // a name was entered but no hash? thats not good!
- // mhh - but this could not happen in a perfect world
- if (download_name && !hash) {
- alert(nothing_themed);
- return false;
- }
-
- // now the opposite: something was themed, but no download name given
- if (!download_name && hash) {
- return window.confirm(name_missing);
- }
-
- // name validation
- if (download_name == 'sunburst') {
- alert(no_sunburst_name);
- return false;
- }
-
- if (download_name.match(/[a-z|0-9|_|-]*/) != download_name) {
- alert(no_special_chars);
- return false;
- }
-
- // if both are given, use it
- if (download_name && hash) {
- jq('input[name=form.themeroller]').val(hash);
- }
- });
-});
Modified: zettwerk.ui/trunk/zettwerk/ui/filesystem.py
==============================================================================
--- zettwerk.ui/trunk/zettwerk/ui/filesystem.py (original)
+++ zettwerk.ui/trunk/zettwerk/ui/filesystem.py Fri Apr 11 07:35:08 2014
@@ -56,6 +56,15 @@
z.close()
+def isCustomTheme(name):
+ """ check if this is a custom file or a default theme """
+ return os.path.exists(
+ os.path.join(DOWNLOAD_HOME,
+ name,
+ 'jquery-ui-1.9.2.custom.css')
+ )
+
+
def getDirectoriesOfDownloadHome():
""" return all directories of the download
home folder. """
Modified: zettwerk.ui/trunk/zettwerk/ui/locales/de/LC_MESSAGES/zettwerk.ui.mo
==============================================================================
Binary files. No diff available.
Modified: zettwerk.ui/trunk/zettwerk/ui/locales/de/LC_MESSAGES/zettwerk.ui.po
==============================================================================
--- zettwerk.ui/trunk/zettwerk/ui/locales/de/LC_MESSAGES/zettwerk.ui.po (original)
+++ zettwerk.ui/trunk/zettwerk/ui/locales/de/LC_MESSAGES/zettwerk.ui.po Fri Apr 11 07:35:08 2014
@@ -1,7 +1,7 @@
msgid ""
msgstr ""
"Project-Id-Version: zettwerk.ui\n"
-"POT-Creation-Date: 2011-06-12 06:44+0000\n"
+"POT-Creation-Date: 2014-04-11 06:43+0000\n"
"PO-Revision-Date: 2010-05-01 07:32+0000\n"
"Last-Translator: Joerg Kubaile <[email protected]>\n"
"Language-Team: zettwerk <[email protected]>\n"
@@ -14,11 +14,15 @@
"Preferred-Encodings: utf-8 latin1\n"
"Domain: zettwerk.ui\n"
-#: ./../browser/cp_view.py:72
+#: ./../browser/cp_view.py:40
+msgid "Add theme"
+msgstr ""
+
+#: ./../browser/cp_view.py:66
msgid "Create download directory at: "
msgstr "Erstelle den Download Ordner an Stelle:"
-#: ./../tool/tool.py:191
+#: ./../tool/tool.py:195
msgid "Directory created"
msgstr "Ordner erstellt"
@@ -30,11 +34,15 @@
msgid "Download name given but nothing themed - please use themeroller"
msgstr "Ein Name wurde angegeben, aber nichts angepasst - verwenden Sie hierzu den Themeroller Link."
+#: ./../browser/cp_view.py:35
+msgid "Existing themes"
+msgstr ""
+
#: ./../tool/tool.py:76
msgid "Name of the theme to download."
msgstr "Name des Themas zum Herunterladen."
-#: ./../browser/cp_view.py:65
+#: ./../browser/cp_view.py:59
msgid "Open jquery.ui themeroller (only firefox)"
msgstr "Öffne jquery.ui themeroller (nur im Firefox)"
@@ -43,8 +51,8 @@
msgstr "Bitte keine Sonderzeichen verwenden."
#: ./../browser/cp_view.py:36
-msgid "Select a theme from your downloaded themes."
-msgstr "Ein Thema aus den Heruntergeladenen auswählen."
+msgid "Select a theme from the existing themes."
+msgstr ""
#: ./../tool/tool.py:104
msgid "Sorry, due to security restrictions, this tool only works in Firefox"
@@ -54,16 +62,14 @@
msgid "Sorry, sunburst is an invalid name"
msgstr "sunburst ist ein reservierter Name der nicht verwendet werden darf."
-#: ./../tool/tool.py:215
+#: ./../tool/tool.py:219
msgid "The downloaded zipfile is corrupt. This could mean that the themeroller webservice has problems. The common fix for this is, to wait a day or two and try it again."
msgstr "Das heruntergeladene Archiv ist fehlerhaft. Dies ist meistens durch Probleme beim Themeroller Dienst verursacht. Um das Problem zu beheben genügt es in der Regel ein oder zwei Tage zu warten und es dann nochmal zu probieren."
-#: ./../browser/cp_view.py:35
#: ./../tool/tool.py:61
msgid "Theme"
msgstr "Thema"
-#: ./../browser/cp_view.py:40
#: ./../tool/tool.py:70
msgid "Themeroller"
msgstr "Themeroller"
@@ -72,17 +78,17 @@
msgid "You opened themeroller, but no download name is given. Click ok to continue and ignore your changes or click cancel to enter a name."
msgstr "Themereoller wurde geöffnet, aber kein Name zum Herunterladen angegeben. Klicken Sie ok um die Änderungen zu verwerfen, oder abbrechen um einen Namen anzugeben."
-#: ./../browser/cp_view.py:93
+#: ./../browser/cp_view.py:87
msgid "Zettwerk UI Themer"
msgstr "Zettwerk UI Themer"
+#. Default: "bla"
+#: ./../browser/cp_view.py:41
+msgid "add_theme_description_text"
+msgstr ""
+
#. Default: "With the theme link, you can choose a theme from your existing themes. The themeroller link is to create and change themes."
-#: ./../browser/cp_view.py:94
+#: ./../browser/cp_view.py:88
msgid "cp_description"
msgstr "Über den Thema Reiter kann aus den vorhanden Themas gewählt werden. Der Themeroller Reiter ist zum Erstellen und Ändern von Themas."
-#. Default: "New themes gets\ndownloaded to your server's filesystem. The target directory for storing them\nis given below. If the folder is not available - downloading is disabled. But\nthis tool can create the directory. If you want to integrate a custom theme\nfrom themeroller do not use the themeroller's download link - that will\ndownload the theme to your local machine. You must use the save button below.\n"
-#: ./../browser/cp_view.py:41
-msgid "theme_description_text"
-msgstr "Neue Themas werden in das Dateisystem des Servers heruntergealden. Das Ziel-Verzeichnis um sie zu speichern ist unten angegeben. Falls dieser Ordner nicht vorhanden ist, ist der Download-Möglichkeit deaktivert. Aber diese Erweiterung kann den Ordner anlegen. Um ein angepasstes Thema zu integrieren darf nicht der Themeroller Download Link verwendet werden - dieser lädt das Thema auf den lokalen Computer. Es muss der Speichern Knopf unten verwendet werden."
-
Modified: zettwerk.ui/trunk/zettwerk/ui/locales/en/LC_MESSAGES/zettwerk.ui.mo
==============================================================================
Binary files. No diff available.
Modified: zettwerk.ui/trunk/zettwerk/ui/locales/en/LC_MESSAGES/zettwerk.ui.po
==============================================================================
--- zettwerk.ui/trunk/zettwerk/ui/locales/en/LC_MESSAGES/zettwerk.ui.po (original)
+++ zettwerk.ui/trunk/zettwerk/ui/locales/en/LC_MESSAGES/zettwerk.ui.po Fri Apr 11 07:35:08 2014
@@ -1,7 +1,7 @@
msgid ""
msgstr ""
"Project-Id-Version: PACKAGE VERSION\n"
-"POT-Creation-Date: 2011-06-12 06:44+0000\n"
+"POT-Creation-Date: 2014-04-11 06:43+0000\n"
"PO-Revision-Date: YEAR-MO-DA HO:MI +ZONE\n"
"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
"Language-Team: LANGUAGE <[email protected]>\n"
@@ -14,11 +14,15 @@
"Preferred-Encodings: utf-8 latin1\n"
"Domain: zettwerk.ui\n"
-#: ./../browser/cp_view.py:72
+#: ./../browser/cp_view.py:40
+msgid "Add theme"
+msgstr ""
+
+#: ./../browser/cp_view.py:66
msgid "Create download directory at: "
msgstr "Create download directory at: "
-#: ./../tool/tool.py:191
+#: ./../tool/tool.py:195
msgid "Directory created"
msgstr "Directory created"
@@ -30,11 +34,15 @@
msgid "Download name given but nothing themed - please use themeroller"
msgstr "Download name given but nothing themed - please use themeroller"
+#: ./../browser/cp_view.py:35
+msgid "Existing themes"
+msgstr ""
+
#: ./../tool/tool.py:76
msgid "Name of the theme to download."
msgstr "Name of the theme to download."
-#: ./../browser/cp_view.py:65
+#: ./../browser/cp_view.py:59
msgid "Open jquery.ui themeroller (only firefox)"
msgstr "Open jquery.ui themeroller (only firefox)"
@@ -43,8 +51,8 @@
msgstr ""
#: ./../browser/cp_view.py:36
-msgid "Select a theme from your downloaded themes."
-msgstr "Select a theme from your downloaded themes."
+msgid "Select a theme from the existing themes."
+msgstr ""
#: ./../tool/tool.py:104
msgid "Sorry, due to security restrictions, this tool only works in Firefox"
@@ -54,16 +62,14 @@
msgid "Sorry, sunburst is an invalid name"
msgstr ""
-#: ./../tool/tool.py:215
+#: ./../tool/tool.py:219
msgid "The downloaded zipfile is corrupt. This could mean that the themeroller webservice has problems. The common fix for this is, to wait a day or two and try it again."
msgstr ""
-#: ./../browser/cp_view.py:35
#: ./../tool/tool.py:61
msgid "Theme"
msgstr "Theme"
-#: ./../browser/cp_view.py:40
#: ./../tool/tool.py:70
msgid "Themeroller"
msgstr "Themeroller"
@@ -72,18 +78,18 @@
msgid "You opened themeroller, but no download name is given. Click ok to continue and ignore your changes or click cancel to enter a name."
msgstr "You opened themeroller, but no download name is given. Click ok to continue and ignore your changes or click cancel to enter a name."
-#: ./../browser/cp_view.py:93
+#: ./../browser/cp_view.py:87
msgid "Zettwerk UI Themer"
msgstr "Zettwerk UI Themer"
+#. Default: "bla"
+#: ./../browser/cp_view.py:41
+msgid "add_theme_description_text"
+msgstr ""
+
#. Default: "With the theme link, you can choose a theme from your existing themes. The themeroller link is to create and change themes."
-#: ./../browser/cp_view.py:94
+#: ./../browser/cp_view.py:88
#, fuzzy
msgid "cp_description"
msgstr "The settings are to enable or disable theming of elements. With the theme link, you can choose a theme from your existing themes. The themeroller link is to create and change themes."
-#. Default: "New themes gets\ndownloaded to your server's filesystem. The target directory for storing them\nis given below. If the folder is not available - downloading is disabled. But\nthis tool can create the directory. If you want to integrate a custom theme\nfrom themeroller do not use the themeroller's download link - that will\ndownload the theme to your local machine. You must use the save button below.\n"
-#: ./../browser/cp_view.py:41
-msgid "theme_description_text"
-msgstr "New themes gets downloaded to your server's filesystem. The target directory for storing theme is given below. If the folder is not available - downloading is disabled. But this tool can create the directory. If you want to integrate a custom theme from themeroller do not use the themeroller's download link - that will download the theme to your local machine. You must use the save button below."
-
Modified: zettwerk.ui/trunk/zettwerk/ui/locales/es/LC_MESSAGES/zettwerk.ui.mo
==============================================================================
Binary files. No diff available.
Modified: zettwerk.ui/trunk/zettwerk/ui/locales/es/LC_MESSAGES/zettwerk.ui.po
==============================================================================
--- zettwerk.ui/trunk/zettwerk/ui/locales/es/LC_MESSAGES/zettwerk.ui.po (original)
+++ zettwerk.ui/trunk/zettwerk/ui/locales/es/LC_MESSAGES/zettwerk.ui.po Fri Apr 11 07:35:08 2014
@@ -1,7 +1,7 @@
msgid ""
msgstr ""
"Project-Id-Version: zettwerk.ui\n"
-"POT-Creation-Date: 2011-06-12 06:44+0000\n"
+"POT-Creation-Date: 2014-04-11 06:43+0000\n"
"PO-Revision-Date: 2011-06-22 11:26-0400\n"
"Last-Translator: Leonardo J. Caballero G. <[email protected]>\n"
"Language-Team: Spanish <[email protected]>\n"
@@ -15,11 +15,15 @@
"Domain: zettwerk.ui\n"
"X-Is-Fallback-For: es-ar es-bo es-cl es-co es-cr es-do es-ec es-es es-sv es-gt es-hn es-mx es-ni es-pa es-py es-pe es-pr es-us es-uy es-ve\n"
-#: ./../browser/cp_view.py:72
+#: ./../browser/cp_view.py:40
+msgid "Add theme"
+msgstr ""
+
+#: ./../browser/cp_view.py:66
msgid "Create download directory at: "
msgstr "Crear descarga en el directorio:"
-#: ./../tool/tool.py:191
+#: ./../tool/tool.py:195
msgid "Directory created"
msgstr "Directorio creado"
@@ -31,11 +35,15 @@
msgid "Download name given but nothing themed - please use themeroller"
msgstr "Nombre para descarga dado, pero a ningún temas aplicado - por favor, use themeroller"
+#: ./../browser/cp_view.py:35
+msgid "Existing themes"
+msgstr ""
+
#: ./../tool/tool.py:76
msgid "Name of the theme to download."
msgstr "Nombre del tema a descargar."
-#: ./../browser/cp_view.py:65
+#: ./../browser/cp_view.py:59
msgid "Open jquery.ui themeroller (only firefox)"
msgstr "Abrir el jquery.ui themeroller (solamente en Mozilla Firefox)"
@@ -44,8 +52,8 @@
msgstr "Por favor, no use caracteres especiales."
#: ./../browser/cp_view.py:36
-msgid "Select a theme from your downloaded themes."
-msgstr "Seleccione un tema desde sus temas descargados."
+msgid "Select a theme from the existing themes."
+msgstr ""
#: ./../tool/tool.py:104
msgid "Sorry, due to security restrictions, this tool only works in Firefox"
@@ -55,16 +63,14 @@
msgid "Sorry, sunburst is an invalid name"
msgstr "Lo siento, sunburst es un nombre invalido"
-#: ./../tool/tool.py:215
+#: ./../tool/tool.py:219
msgid "The downloaded zipfile is corrupt. This could mean that the themeroller webservice has problems. The common fix for this is, to wait a day or two and try it again."
msgstr "El archivo comprimido .zip descargado esta corrupto. Este podría significar que el servicio web de themeroller tiene problemas. La solución común a esto es, esperar un día o dos y intente de nuevo."
-#: ./../browser/cp_view.py:35
#: ./../tool/tool.py:61
msgid "Theme"
msgstr "Tema"
-#: ./../browser/cp_view.py:40
#: ./../tool/tool.py:70
msgid "Themeroller"
msgstr "Themeroller"
@@ -73,23 +79,17 @@
msgid "You opened themeroller, but no download name is given. Click ok to continue and ignore your changes or click cancel to enter a name."
msgstr "Su themeroller esta abierto, pero no tiene nombre para descarga dado. Haga clic en el botón Aceptar para continuar y ignorar los cambios o haga clic en el botón Cancelar pata introducir un nombre."
-#: ./../browser/cp_view.py:93
+#: ./../browser/cp_view.py:87
msgid "Zettwerk UI Themer"
msgstr "Zettwerk UI Themer"
+#. Default: "bla"
+#: ./../browser/cp_view.py:41
+msgid "add_theme_description_text"
+msgstr ""
+
#. Default: "With the theme link, you can choose a theme from your existing themes. The themeroller link is to create and change themes."
-#: ./../browser/cp_view.py:94
+#: ./../browser/cp_view.py:88
msgid "cp_description"
msgstr "Con el enlace de tema, usted puede elegir un tema de sus temas ya existentes. El enlace themeroller es para crear y cambiar los temas."
-#. Default: "New themes gets\ndownloaded to your server's filesystem. The target directory for storing them\nis given below. If the folder is not available - downloading is disabled. But\nthis tool can create the directory. If you want to integrate a custom theme\nfrom themeroller do not use the themeroller's download link - that will\ndownload the theme to your local machine. You must use the save button below.\n"
-#: ./../browser/cp_view.py:41
-msgid "theme_description_text"
-msgstr ""
-"Los nuevos temas se\n"
-"descarga al sistema de archivos de su servidor. El directorio de destino para el almacenamiento de ellos\n"
-"es que mostrado a continuación. Si la carpeta no está disponible - la descarga está desactivada. Pero\n"
-"esta herramienta puede crear el directorio. Si desea integrar un tema personalizado\n"
-"en themeroller no utilice el enlace de descarga de themeroller - el cual descargará\n"
-"el tema en su máquina local. Debe utilizar el botón \"Guardar\" a continuación."
-
Modified: zettwerk.ui/trunk/zettwerk/ui/locales/fr/LC_MESSAGES/zettwerk.ui.mo
==============================================================================
Binary files. No diff available.
Modified: zettwerk.ui/trunk/zettwerk/ui/locales/fr/LC_MESSAGES/zettwerk.ui.po
==============================================================================
--- zettwerk.ui/trunk/zettwerk/ui/locales/fr/LC_MESSAGES/zettwerk.ui.po (original)
+++ zettwerk.ui/trunk/zettwerk/ui/locales/fr/LC_MESSAGES/zettwerk.ui.po Fri Apr 11 07:35:08 2014
@@ -4,7 +4,7 @@
msgid ""
msgstr ""
"Project-Id-Version: PACKAGE VERSION\n"
-"POT-Creation-Date: 2011-06-12 06:44+0000\n"
+"POT-Creation-Date: 2014-04-11 06:43+0000\n"
"PO-Revision-Date: YEAR-MO-DA HO:MI +ZONE\n"
"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
"Language-Team: LANGUAGE <[email protected]>\n"
@@ -17,11 +17,15 @@
"Preferred-Encodings: utf-8 latin1\n"
"Domain: zettwerk.ui\n"
-#: ./../browser/cp_view.py:72
+#: ./../browser/cp_view.py:40
+msgid "Add theme"
+msgstr ""
+
+#: ./../browser/cp_view.py:66
msgid "Create download directory at: "
msgstr "Créer un dossier de téléchargement sur le serveur: "
-#: ./../tool/tool.py:191
+#: ./../tool/tool.py:195
msgid "Directory created"
msgstr "Dossier créé"
@@ -33,11 +37,15 @@
msgid "Download name given but nothing themed - please use themeroller"
msgstr "Nom de téléchargement donné mais aucun thème - merci d'utiliser le themeroller"
+#: ./../browser/cp_view.py:35
+msgid "Existing themes"
+msgstr ""
+
#: ./../tool/tool.py:76
msgid "Name of the theme to download."
msgstr "Nom du thème à télécharger."
-#: ./../browser/cp_view.py:65
+#: ./../browser/cp_view.py:59
msgid "Open jquery.ui themeroller (only firefox)"
msgstr "Ouvrir jquery.ui themeroller (seulement pour Firefox)"
@@ -46,8 +54,8 @@
msgstr "Merci de ne pas utiliser de caractères spéciaux."
#: ./../browser/cp_view.py:36
-msgid "Select a theme from your downloaded themes."
-msgstr "Séléctionner un thème à partir des thèmes téléchargés."
+msgid "Select a theme from the existing themes."
+msgstr ""
#: ./../tool/tool.py:104
msgid "Sorry, due to security restrictions, this tool only works in Firefox"
@@ -57,16 +65,14 @@
msgid "Sorry, sunburst is an invalid name"
msgstr "Désolé, sunburst est un nom invalide"
-#: ./../tool/tool.py:215
+#: ./../tool/tool.py:219
msgid "The downloaded zipfile is corrupt. This could mean that the themeroller webservice has problems. The common fix for this is, to wait a day or two and try it again."
msgstr "Le fichier zip téléchargé est corrompus. Ceci peut signifier que le webservice themeroller rencontre des problèmes. Vous pouvez attendre un jour ou deux et re-essayer."
-#: ./../browser/cp_view.py:35
#: ./../tool/tool.py:61
msgid "Theme"
msgstr "Thème"
-#: ./../browser/cp_view.py:40
#: ./../tool/tool.py:70
msgid "Themeroller"
msgstr "Themeroller"
@@ -75,17 +81,17 @@
msgid "You opened themeroller, but no download name is given. Click ok to continue and ignore your changes or click cancel to enter a name."
msgstr "Vous avez ouvert themeroller mais vous n'avez pas donné de nom. Cliquer sur OK pour continuer et ignorer vos modifications ou cliquer sur Cancel pour entrer un nom."
-#: ./../browser/cp_view.py:93
+#: ./../browser/cp_view.py:87
msgid "Zettwerk UI Themer"
msgstr "Thèmes Zettwerk UI"
+#. Default: "bla"
+#: ./../browser/cp_view.py:41
+msgid "add_theme_description_text"
+msgstr ""
+
#. Default: "With the theme link, you can choose a theme from your existing themes. The themeroller link is to create and change themes."
-#: ./../browser/cp_view.py:94
+#: ./../browser/cp_view.py:88
msgid "cp_description"
msgstr "Avec le lien de thème, vous pouvez choisir un thème à partir des thèmes existants. Le lien themeroller permet de créer ou modifier les thèmes."
-#. Default: "New themes gets\ndownloaded to your server's filesystem. The target directory for storing them\nis given below. If the folder is not available - downloading is disabled. But\nthis tool can create the directory. If you want to integrate a custom theme\nfrom themeroller do not use the themeroller's download link - that will\ndownload the theme to your local machine. You must use the save button below.\n"
-#: ./../browser/cp_view.py:41
-msgid "theme_description_text"
-msgstr "De nouveaux thèmes ont été téléchargé sur le système de fichier du serveur. Le dossier de destination pour les stocker est indiqué ci dessous. So le dossier n'est pas disponible - le téléchargement est désactivé. Mais cet outil peut créer le dossier. Si vous souhaitez intégrer un thème personnalisé à partir du themeroller, n'utilisez pas le lien du themeroller - ceci téléchargera le thème sur votre machine personnelle. Vous devez utiliser bouton d'enregistrement ci dessous."
-
Modified: zettwerk.ui/trunk/zettwerk/ui/locales/zettwerk.ui.pot
==============================================================================
--- zettwerk.ui/trunk/zettwerk/ui/locales/zettwerk.ui.pot (original)
+++ zettwerk.ui/trunk/zettwerk/ui/locales/zettwerk.ui.pot Fri Apr 11 07:35:08 2014
@@ -4,7 +4,7 @@
msgid ""
msgstr ""
"Project-Id-Version: PACKAGE VERSION\n"
-"POT-Creation-Date: 2011-06-12 06:44+0000\n"
+"POT-Creation-Date: 2014-04-11 06:43+0000\n"
"PO-Revision-Date: YEAR-MO-DA HO:MI +ZONE\n"
"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
"Language-Team: LANGUAGE <[email protected]>\n"
@@ -17,11 +17,15 @@
"Preferred-Encodings: utf-8 latin1\n"
"Domain: zettwerk.ui\n"
-#: ./../browser/cp_view.py:72
+#: ./../browser/cp_view.py:40
+msgid "Add theme"
+msgstr ""
+
+#: ./../browser/cp_view.py:66
msgid "Create download directory at: "
msgstr ""
-#: ./../tool/tool.py:191
+#: ./../tool/tool.py:195
msgid "Directory created"
msgstr ""
@@ -33,11 +37,15 @@
msgid "Download name given but nothing themed - please use themeroller"
msgstr ""
+#: ./../browser/cp_view.py:35
+msgid "Existing themes"
+msgstr ""
+
#: ./../tool/tool.py:76
msgid "Name of the theme to download."
msgstr ""
-#: ./../browser/cp_view.py:65
+#: ./../browser/cp_view.py:59
msgid "Open jquery.ui themeroller (only firefox)"
msgstr ""
@@ -46,7 +54,7 @@
msgstr ""
#: ./../browser/cp_view.py:36
-msgid "Select a theme from your downloaded themes."
+msgid "Select a theme from the existing themes."
msgstr ""
#: ./../tool/tool.py:104
@@ -57,16 +65,14 @@
msgid "Sorry, sunburst is an invalid name"
msgstr ""
-#: ./../tool/tool.py:215
+#: ./../tool/tool.py:219
msgid "The downloaded zipfile is corrupt. This could mean that the themeroller webservice has problems. The common fix for this is, to wait a day or two and try it again."
msgstr ""
-#: ./../browser/cp_view.py:35
#: ./../tool/tool.py:61
msgid "Theme"
msgstr ""
-#: ./../browser/cp_view.py:40
#: ./../tool/tool.py:70
msgid "Themeroller"
msgstr ""
@@ -75,17 +81,17 @@
msgid "You opened themeroller, but no download name is given. Click ok to continue and ignore your changes or click cancel to enter a name."
msgstr ""
-#: ./../browser/cp_view.py:93
+#: ./../browser/cp_view.py:87
msgid "Zettwerk UI Themer"
msgstr ""
-#. Default: "With the theme link, you can choose a theme from your existing themes. The themeroller link is to create and change themes."
-#: ./../browser/cp_view.py:94
-msgid "cp_description"
+#. Default: "bla"
+#: ./../browser/cp_view.py:41
+msgid "add_theme_description_text"
msgstr ""
-#. Default: "New themes gets\ndownloaded to your server's filesystem. The target directory for storing them\nis given below. If the folder is not available - downloading is disabled. But\nthis tool can create the directory. If you want to integrate a custom theme\nfrom themeroller do not use the themeroller's download link - that will\ndownload the theme to your local machine. You must use the save button below.\n"
-#: ./../browser/cp_view.py:41
-msgid "theme_description_text"
+#. Default: "With the theme link, you can choose a theme from your existing themes. The themeroller link is to create and change themes."
+#: ./../browser/cp_view.py:88
+msgid "cp_description"
msgstr ""
Modified: zettwerk.ui/trunk/zettwerk/ui/static/gui.js
==============================================================================
--- zettwerk.ui/trunk/zettwerk/ui/static/gui.js (original)
+++ zettwerk.ui/trunk/zettwerk/ui/static/gui.js Fri Apr 11 07:35:08 2014
@@ -1,4 +1,4 @@
-jq(document).ready(function() {
+$(document).ready(function() {
enablePersonalTool();
enableForms();
enableDialogs();
@@ -10,7 +10,7 @@
var enablePersonalTool = function() {
// enable overlay, cause the id is changed
// taken from Products.CMFPlone.skins.plone_ecmascript/popupforms.js
- jq('#portal-personaltools-ui a[href$="/login"], #portal-personaltools-ui a[href$="/login_form"]').prepOverlay(
+ $('#portal-personaltools-ui a[href$="/login"], #portal-personaltools-ui a[href$="/login_form"]').prepOverlay(
{
subtype: 'ajax',
filter: common_content_filter,
@@ -34,47 +34,47 @@
);
// custom stuff
- jq('#portal-personaltools-ui').hover(function() {
- jq(this).addClass('ui-state-hover');
+ $('#portal-personaltools-ui').hover(function() {
+ $(this).addClass('ui-state-hover');
}, function() {
- jq(this).removeClass('ui-state-hover');
+ $(this).removeClass('ui-state-hover');
});
- jq('#portal-personaltools-ui dd a').hover(function() {
- jq(this).addClass('ui-state-hover');
+ $('#portal-personaltools-ui dd a').hover(function() {
+ $(this).addClass('ui-state-hover');
}, function() {
- jq(this).removeClass('ui-state-hover');
+ $(this).removeClass('ui-state-hover');
});
};
var enableForms = function($content) {
if (!$content) {
- var $content = jq('body');
+ var $content = $('body');
}
$content.find('.optionsToggle').removeClass('optionsToggle');
$content.find('select, textarea, input:text, input:password').bind({
focusin: function() {
- jq(this).addClass('ui-state-focus');
+ $(this).addClass('ui-state-focus');
},
focusout: function() {
- jq(this).removeClass('ui-state-focus');
+ $(this).removeClass('ui-state-focus');
}
});
$content.find(".hover").hover(function(){
- jq(this).addClass("ui-state-hover");
+ $(this).addClass("ui-state-hover");
},function(){
- jq(this).removeClass("ui-state-hover");
+ $(this).removeClass("ui-state-hover");
});
}
var enableDialogs = function() {
- jq("a.link-overlay").unbind('click').click(function() {
+ $("a.link-overlay").unbind('click').click(function() {
// remove old dialogs
- jq('#dialogContainer').remove();
+ $('#dialogContainer').remove();
// use the links content as default title of the dialog
- var title = jq(this).html();
- $.get(jq(this).attr('href'),
+ var title = $(this).html();
+ $.get($(this).attr('href'),
{},
function(data) {
showDialogContent(data,title)
@@ -83,13 +83,13 @@
return false; // avoid the execution of the regular link
});
- jq("form.link-overlay input[type='submit']").unbind('click').click(function() {
+ $("form.link-overlay input[type='submit']").unbind('click').click(function() {
// remove old dialogs
- jq('#dialogContainer').remove();
+ $('#dialogContainer').remove();
// use the links content as default title of the dialog
var title = '';
- $.get(jq(this).parents('form').attr('action'),
+ $.get($(this).parents('form').attr('action'),
{},
function(data) {
showDialogContent(data,title)
@@ -100,51 +100,51 @@
};
var showDialogContent = function(data, title) {
- var $content = jq(data).find('#content');
+ var $content = $(data).find('#content');
// take the first heading as dialog title, if available
$content.find('h1.documentFirstHeading').each(function() {
- title = jq(this).html();
- jq(this).hide();
+ title = $(this).html();
+ $(this).hide();
});
- jq('<div id="dialogContainer" title="'+title+'"></div>').appendTo('body');
+ $('<div id="dialogContainer" title="'+title+'"></div>').appendTo('body');
// search for submit buttons and use them as dialog buttons
var buttons = {};
$content.find('input[type=submit]').each(function() {
- var buttonValue = jq(this).val();
+ var buttonValue = $(this).val();
buttons[buttonValue] = function() {
- jq('input[type=submit][value='+buttonValue+']').click();
+ $('input[type=submit][value='+buttonValue+']').click();
};
- jq(this).hide();
+ $(this).hide();
});
// bring up the dialog
$content.appendTo('#dialogContainer');
enableForms($content);
- var $dialog = jq('#dialogContainer').dialog({width: '60%', buttons: buttons});
+ var $dialog = $('#dialogContainer').dialog({width: '60%', buttons: buttons});
};
var enableTabs = function() {
- jq('div.ui-tabs > ul > li').hover(function() {
- jq(this).addClass('ui-state-hover');
- jq(this).find('span').addClass('ui-state-hover');
+ $('div.ui-tabs > ul > li').hover(function() {
+ $(this).addClass('ui-state-hover');
+ $(this).find('span').addClass('ui-state-hover');
}, function() {
- jq(this).removeClass('ui-state-hover');
- jq(this).find('span').removeClass('ui-state-hover');
+ $(this).removeClass('ui-state-hover');
+ $(this).find('span').removeClass('ui-state-hover');
});
- jq('div.ui-tabs > ul > li a').click(function() {
+ $('div.ui-tabs > ul > li a').click(function() {
// handle the tabs
- jq(this).parent().parent().find('.ui-state-active').removeClass('ui-state-active');
- jq(this).parent().addClass('ui-state-active');
- jq(this).find('span').addClass('ui-state-active');
+ $(this).parent().parent().find('.ui-state-active').removeClass('ui-state-active');
+ $(this).parent().addClass('ui-state-active');
+ $(this).find('span').addClass('ui-state-active');
// hide all fieldsets
- jq('div.ui-tabs>fieldset,div.ui-tabs>dd').hide();
+ $('div.ui-tabs>fieldset,div.ui-tabs>dd').hide();
- var active_id = jq(this).attr('href'); // thats the hidden legend in the fieldset
- var $active = jq(active_id);
+ var active_id = $(this).attr('href'); // thats the hidden legend in the fieldset
+ var $active = $(active_id);
if ($active[0].tagName.toLowerCase() == 'dd') {
$active.show();
@@ -153,14 +153,14 @@
}
return false;
});
- jq('ul.ui-tabs-nav').find('.selected').parent().addClass('ui-state-active');
+ $('ul.ui-tabs-nav').find('.selected').parent().addClass('ui-state-active');
};
var enableGlobalTabs = function() {
- jq('#portal-globalnav-ui > li').hover(function() {
- jq(this).addClass('ui-state-hover');
+ $('#portal-globalnav-ui > li').hover(function() {
+ $(this).addClass('ui-state-hover');
}, function() {
- jq(this).removeClass('ui-state-hover');
+ $(this).removeClass('ui-state-hover');
});
};
@@ -170,30 +170,30 @@
}
var enableEditBar2 = function() {
- if (jq('#edit-bar-ui').length) {
+ if ($('#edit-bar-ui').length) {
window.clearInterval(edit_bar_interval);
- jq('#content-views-ui li a').hover(function() {
- jq(this).addClass('ui-state-hover');
+ $('#content-views-ui li a').hover(function() {
+ $(this).addClass('ui-state-hover');
}, function() {
- jq(this).removeClass('ui-state-hover');
+ $(this).removeClass('ui-state-hover');
});
- jq('#content-views-ui li a').css('border', '0').css('line-height', '2em');
+ $('#content-views-ui li a').css('border', '0').css('line-height', '2em');
- jq('#contentActionMenus-ui dl.actionMenu').hover(function() {
- jq(this).addClass('ui-state-hover ui-corner-bottom').css('border', '0px');
+ $('#contentActionMenus-ui dl.actionMenu').hover(function() {
+ $(this).addClass('ui-state-hover ui-corner-bottom').css('border', '0px');
}, function() {
- jq(this).removeClass('ui-state-hover ui-corner-bttom');
+ $(this).removeClass('ui-state-hover ui-corner-bttom');
});
- jq('#contentActionMenus-ui a.actionMenuSelected').addClass('ui-state-default ui-corner-all');
- jq('#contentActionMenus-ui a').addClass('ui-corner-all');
- jq('#contentActionMenus-ui a').hover(function() {
- jq(this).addClass('ui-state-hover');
+ $('#contentActionMenus-ui a.actionMenuSelected').addClass('ui-state-default ui-corner-all');
+ $('#contentActionMenus-ui a').addClass('ui-corner-all');
+ $('#contentActionMenus-ui a').hover(function() {
+ $(this).addClass('ui-state-hover');
}, function() {
- jq(this).removeClass('ui-state-hover');
+ $(this).removeClass('ui-state-hover');
});
- jq('dd.actionMenuContent').addClass('ui-state-active');
+ $('dd.actionMenuContent').addClass('ui-state-active');
}
}
Modified: zettwerk.ui/trunk/zettwerk/ui/tool/tool.py
==============================================================================
--- zettwerk.ui/trunk/zettwerk/ui/tool/tool.py (original)
+++ zettwerk.ui/trunk/zettwerk/ui/tool/tool.py Fri Apr 11 07:35:08 2014
@@ -16,7 +16,7 @@
from ..filesystem import extractZipFile, storeBinaryFile, \
createDownloadFolder, getDirectoriesOfDownloadHome, \
- getThemeHashOfCustomCSS
+ getThemeHashOfCustomCSS, isCustomTheme
from ..resources import registerResourceDirectory
from ..filesystem import DOWNLOAD_HOME
@@ -70,12 +70,6 @@
title=_("Themeroller")
)
- download = schema.TextLine(
- title=_("Download"),
- required=False,
- description=_("Name of the theme to download.")
- )
-
class IUITool(IUIToolTheme, IUIToolThemeroller):
""" Mixin Interface """
@@ -138,9 +132,13 @@
'sunburst/jqueryui.css";'
else:
resource_base = '++resource++zettwerk.ui.themes'
- result += '@import "%s/%s/jquery-ui-.custom.css";' % (
+ css_filename = 'jquery.ui.theme.css';
+ if isCustomTheme(self.theme):
+ css_filename = 'jquery-ui-1.9.2.custom.css'
+ result += '@import "%s/%s/%s";' % (
resource_base,
- self.theme
+ self.theme,
+ css_filename
)
return result
------------------------------------------------------------------------------
Put Bad Developers to Shame
Dominate Development with Jenkins Continuous Integration
Continuously Automate Build, Test & Deployment
Start a new project now. Try Jenkins in the cloud.
http://p.sf.net/sfu/13600_Cloudbees
_______________________________________________
Collective-checkins mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/collective-checkins
--- zettwerk.ui/trunk/zettwerk/ui/browser/cp_view.py (original)
+++ zettwerk.ui/trunk/zettwerk/ui/browser/cp_view.py Fri Apr 11 07:35:08 2014
@@ -32,43 +32,21 @@
theme = FormFieldsets(IUIToolTheme)
theme.id = 'theme'
-theme.label = _(u"Theme")
-theme.description = _(u'Select a theme from your downloaded themes.')
+theme.label = _(u"Existing themes")
+theme.description = _(u'Select a theme from the existing themes.')
themeroller = FormFieldsets(IUIToolThemeroller)
themeroller.id = 'themeroller'
-themeroller.label = _('Themeroller')
-themeroller.description = _(u"theme_description_text", """New themes gets
-downloaded to your server's filesystem. The target directory for storing them
-is given below. If the folder is not available - downloading is disabled. But
-this tool can create the directory. If you want to integrate a custom theme
-from themeroller do not use the themeroller's download link - that will
-download the theme to your local machine. You must use the save button below.
-""")
+themeroller.label = _('Add theme')
-class ThemerollerDisplayWidget(DisplayWidget):
- """ Display the themeroller link """
+class ThemeDisplayWidget(DisplayWidget):
+ """ Display the create directory link """
def __call__(self):
tool = self.context.context
tool._rebuildThemeHashes()
- if tool.theme and tool.themeHashes:
- hash = tool.themeHashes.get(tool.theme, '')
- themeroller = u"javascript:callThemeroller('%s')" % (hash)
- else:
- themeroller = u"javascript:callThemeroller()"
- open_link = '<a href="%s">%s</a>' % (
- themeroller,
- translate(
- _(u"Open jquery.ui themeroller (only firefox)"),
- domain="zettwerk.ui",
- context=self.request
- )
- )
- themeroller_input = '<input type="hidden" name="form.themeroller" ' \
- 'value="" />'
create_help = translate(_(u"Create download directory at: "),
domain="zettwerk.ui",
context=self.request)
@@ -77,7 +55,29 @@
u'href="javascript:createDLDirectory()">%s</a>' % (create_text)
if isAvailable():
- return '%s %s' % (open_link, themeroller_input)
+ return _(u"add_theme_description_text", """<p>Sadly,
+ the on the fly themeroller integration does not work anymore. But
+ it is possible, to download and add new themes by hand. There are
+ two kind of themes: Jquery UI Default themes and custom ones.</p>
+ <p>To include all the default themes follow these steps:
+ <ol>
+ <li>Download the zip file from <a href="http://jqueryui.com/resources/download/jquery-ui-themes-1.9.2.zip">http://jqueryui.com/resources/download/jquery-ui-themes-1.9.2.zip</a></li>
+ <li>Extract the contents/subfolders of the themes folder to your download directory.</li>
+ <li>Reload this page and choose a theme.</li>
+ </ol>
+ </p>
+ <p style="margin-top: 2em">To include a custom theme follow these steps:
+ <ol>
+ <li>Go to the themeroller page at <a target="_blank" href="http://jqueryui.com/themeroller/">http://jqueryui.com/themeroller/</a> and create your theme with the themeroller tool.</li>
+ <li>Click Download theme (in the themeroller widget)</li>
+ <li>On the next page, choose the legacy Version (1.9.2 at the moment)</li>
+ <li>Scroll to the bottom of the page set a folder name which gets the theme name.</li>
+ <li>Click download</li>
+ <li>Extract the folder css/$your_theme_name to your download directory.</li>
+ <li>Reload this page and choose a theme.</li>
+ </ol>
+ </p>
+ """)
else:
return create_dl
@@ -86,29 +86,15 @@
""" Build the ControlPanel form. """
form_fields = FormFieldsets(theme, themeroller)
-
- form_fields['themeroller'].custom_widget = ThemerollerDisplayWidget
+ form_fields['themeroller'].custom_widget = ThemeDisplayWidget
form_fields['themeroller'].for_display = True
label = _(u"Zettwerk UI Themer")
description = _('cp_description',
u'With the theme link, you can choose ' \
u'a theme from your existing themes. The ' \
u'themeroller link is to create and change themes.'
)
- def _on_save(self, data):
- """ handle themeroller download """
- name = data.get('download', '')
- if name:
- ## why is form.themeroller not available via data?
- theme_hash = self.request.get('form.themeroller', '')
- if theme_hash:
- tool = self.context
-
- ## also note, that tool.theme gets set via tool directly
- tool.handleDownload(name, theme_hash)
-
- ## and reset the values, they are not needed anymore
- tool.download = ''
- tool.themeroller = ''
+ # def __call__(self):
+ #
Modified: zettwerk.ui/trunk/zettwerk/ui/browser/scripts/cp.js
==============================================================================
@@ -86,29 +86,15 @@
label = _(u"Zettwerk UI Themer")
description = _('cp_description',
- u'With the theme link, you can choose ' \
- u'a theme from your existing themes. The ' \
- u'themeroller link is to create and change themes.'
+ u'With the Existing themes link, you can choose ' \
+ u'a theme from your existing ones. The ' \
+ u'add theme link describes how to add new themes.'
)